@@ -6,7 +6,11 @@ import base64
 import logging
 import requests
 
-class IterableObject:
+class IterableObjectEncoder(json.JSONEncoder):
+    def default(self, obj):
+        return obj.source
+
+class IterableObject(object):
     """
     Wraps a dictionary and makes it feel and
     look like an object but with the power of being iterable.
@@ -19,7 +23,7 @@ class IterableObject:
 
     def __getattr__(self, key):
         if not key in self.source:
-            raise AttributeError("Object has not attribute '{k}'".format(n=key))
+            raise AttributeError("Object has not attribute '{k}'".format(k=key))
 
         return self.source[key]
 
@@ -28,13 +32,16 @@ class IterableObject:
 
     def __contains__(self, key):
         return key in self.source
-        
+    
     def __repr__(self):
         return str(self)
 
     def __str__(self):
         return str(self.source)
 
+    def to_json(self):
+        return json.dumps(self, cls=IterableObjectEncoder)
+
 class DictionaryUtility:
     """
     Utility methods for dealing with dictionaries.
